# Changelog

## [0.3.3-alpha](https://github.com/instill-ai/protogen-python/compare/v0.3.2-alpha...v0.3.3-alpha) (2022-09-14)


### Miscellaneous Chores

* release 0.3.3-alpha ([8f59628](https://github.com/instill-ai/protogen-python/commit/8f5962894723b233d27c08f84aa684a8e67bc3c2))

## [0.3.2-alpha](https://github.com/instill-ai/protogen-python/compare/v0.3.1-alpha...v0.3.2-alpha) (2022-09-13)


### Miscellaneous Chores

* release 0.3.2-alpha ([c60a199](https://github.com/instill-ai/protogen-python/commit/c60a19930daac6648a0fc1c1e78424480e9300f5))

## [0.3.1-alpha](https://github.com/instill-ai/protogen-python/compare/v0.1.5-alpha...v0.3.1-alpha) (2022-08-17)


### Miscellaneous Chores

* release 0.2.0-alpha ([e925396](https://github.com/instill-ai/protogen-python/commit/e925396cf409993b2fa40550a924248be0811d88))
* release 0.2.1-alpha ([03de6f4](https://github.com/instill-ai/protogen-python/commit/03de6f4e989bbd0e136eafa17cdb5dd3089ce4ab))
* release 0.3.1-alpha ([eb5839b](https://github.com/instill-ai/protogen-python/commit/eb5839bb620b9850d0a628db6fa9b47e5571531d))

### [0.1.5-alpha](https://github.com/instill-ai/protogen-python/compare/v0.1.4-alpha...v0.1.5-alpha) (2022-03-22)


### Miscellaneous Chores

* release 0.1.5-alpha ([1ea9082](https://github.com/instill-ai/protogen-python/commit/1ea90826c0402450405755064ec7ffdd9209b131))

### [0.1.4-alpha](https://github.com/instill-ai/protogen-python/compare/v0.1.3-alpha...v0.1.4-alpha) (2022-03-21)


### Miscellaneous Chores

* release 0.1.4-alpha ([1505cbe](https://github.com/instill-ai/protogen-python/commit/1505cbec14927b8897b57f338d6e771682df78c8))

### [0.1.3-alpha](https://github.com/instill-ai/protogen-python/compare/v0.1.2-alpha...v0.1.3-alpha) (2022-03-16)


### Miscellaneous Chores

* release 0.1.3-alpha ([4fa6f1d](https://github.com/instill-ai/protogen-python/commit/4fa6f1da4313b7eef6340607623a73c945e50309))
